==> glpi_0.71.5.orig.tar.gz: glpi/lib/tiny_mce/langs/sk.js <==
tinyMCE.addI18n({sk:{
common:{
edit_confirm:"Chce\u0161 pou\u017Ei\u0165 WYSIWYG m\u00F3d pre tento text?",
apply:"Pou\u017Ei\u0165",
insert:"Vlo\u017Ei\u0165",
update:"Aktualizova\u0165",
cancel:"Zru\u0161i\u0165",
close:"Zavrie\u0165",
browse:"Prech\u00E1dza\u0165",
class_name:"Trieda",
not_set:"-- Nezadan\u00E9 --",
clipboard_msg:"Funkcie Kop\u00EDrova\u0165/vysrihn\u00FA\u0165/vlo\u017Ei\u0165 nie su podporovan\u00E9 prehliada\u010Dmi Mozilla a Firefox.\nChcete viac inform\u00E1ci\u00ED o tomto probl\u00E9me?",
clipboard_no_support:"Moment\u00E1lne nie je podporovan\u00E9 tvoj\u00EDm prehliada\u010Dom. Miesto toho pou\u017Ei kl\u00E1vesov\u00FA skratku.",
popup_blocked:"Ospravedl\u0148ujeme sa, ale blokova\u010D vyskakovac\u00EDch okien neumo\u017Enil otvori\u0165 okno, ktor\u00E9 zprostredkov\u00E1v\u00E1 funk\u010Dnos\u0165 aplik\u00E1ce. Mus\u00EDte vypnu\u0165 blokovanie vyskakovac\u00EDch okien na tomto webe, abyste vyu\u017Eili jeho pln\u00FA funk\u010Dnos\u0165.",
invalid_data:"Chyba: Zadan\u00E9 neplatn\u00E9 hodnoty (zv\u00FDraznen\u00E9 \u010Dervenou)",
more_colors:"Viac farieb"
},
contextmenu:{
align:"Umietnenie",
left:"V\u013Eavo",
center:"Na stred",
right:"Vpravo",
full:"Full"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Vlo\u017Ei\u0165 d\u00E1tum",
inserttime_desc:"Vlo\u017Ei\u0165 \u010Das",
months_long:"Janu\u00E1r,Febru\u00E1r,Marec,Apr\u00EDl,M\u00E1j,J\u00FAn,J\u00FAl,August,September,Okt\u00F3ber,November,December",
months_short:"Jan,Feb,Mar,Apr,M\u00E1j,J\u00FAn,J\u00FAl,Aug,Sep,Okt,Nov,Dec",
day_long:"Nede\u013Ea,Pondelok,Utorok,Strede,\u0160tvrtok,Piatok,Sobota,Nede\u013Ea",
day_short:"Ned,Pon,Ut,Str,\u0160tvr,Pia,Sob,Ned"
},
print:{
print_desc:"Vytla\u010Di\u0165"
},
preview:{
preview_desc:"N\u00E1h\u013Ead"
},
directionality:{
ltr_desc:"Smer z \u013Eava do prava",
rtl_desc:"Smer z prava do \u013Eava"
},
layer:{
insertlayer_desc:"Vlo\u017Ei\u0165 nov\u00FA vrstvu",
forward_desc:"Posun\u00FA\u0165 dopredu",
backward_desc:"Posun\u00FA\u0165 dozadu",
absolute_desc:"Prepn\u00FA\u0165 na absol\u00FAtne poziciovanie",
content:"Nav\u00E1 vrstva..."
},
save:{
save_desc:"Ulo\u017Ei\u0165",
cancel_desc:"Zru\u0161i\u0165 v\u0161etky zmeny"
},
nonbreaking:{
nonbreaking_desc:"Vlo\u017Ei\u0165 znak non-breaking space"
},
iespell:{
iespell_desc:"Spusti\u0165 kontrolu pravopisu",
download:"ieSpell nebol n\u00E1jden\u00FD. Klikni na OK a prejdi na str\u00E1nku prevzatia."
},
advhr:{
advhr_desc:"Horizont\u00E1lna \u010Diara"
},
emotions:{
emotions_desc:"Emotikony"
},
searchreplace:{
search_desc:"N\u00E1jdi",
replace_desc:"N\u00E1jdi/Nahra\u010F"
},
advimage:{
image_desc:"Vlo\u017Ei\u0165/editova\u0165 obr\u00E1zok"
},
advlink:{
link_desc:"Vlo\u017Ei\u0165/editova\u0165 odkaz"
},
xhtmlxtras:{
cite_desc:"Cit\u00E1cia",
abbr_desc:"Skratka",
acronym_desc:"Acronym",
del_desc:"Zru\u0161enie",
ins_desc:"Vlo\u017Eenie",
attribs_desc:"Vlo\u017Ei\u0165/editova\u0165 atrib\u00FAty"
},
style:{
desc:"Editova\u0165 CSS \u0160t\u00FDl"
},
paste:{
paste_text_desc:"Vlo\u017Ei\u0165 ako neformatovan\u00FD text",
paste_word_desc:"Vlo\u017Ei\u0165 text z aplik\u00E1ce Word",
selectall_desc:"Ozna\u010Di\u0165 v\u0161etko"
},
paste_dlg:{
text_title:"Pou\u017Eite CTRL+V na kl\u00E1vesnici pre vlo\u017Eenie textu do okna.",
text_linebreaks:"Zachova\u0165 zalamovanie riadkov",
word_title:"Pou\u017Eite CTRL+V na kl\u00E1vesnici pre vlo\u017Eenie textu do okna."
},
table:{
desc:"Vlo\u017Ei\u0165 nov\u00FA tabu\u013Eku",
row_before_desc:"Vlo\u017Ei\u0165 riadok pred",
row_after_desc:"Vlo\u017Ei\u0165 riadok za",
delete_row_desc:"Odstr\u00E1ni\u0165 riadok",
col_before_desc:"Vlo\u017Ei\u0165 st\u013Apec pred",
col_after_desc:"Vlo\u017Ei\u0165 st\u013Apec za",
delete_col_desc:"Odstr\u00E1ni\u0165 st\u013Apec",
split_cells_desc:"Rozdeli\u0165 zl\u00FAcen\u00E9 bunky",
merge_cells_desc:"Zl\u00FA\u010Di\u0165 bunky",
row_desc:"Vlastnosti riadky tabu\u013Eky",
cell_desc:"Vlastnosti bunky tabu\u013Eky",
props_desc:"Vlastnosti tabu\u013Eky",
paste_row_before_desc:"Vlo\u017Ei\u0165 riadok pred",
paste_row_after_desc:"Vlo\u017Ei\u0165 riadok za",
cut_row_desc:"Vystrihn\u00FA\u0165 riadok",
copy_row_desc:"Kop\u00EDrova\u0165 riadok",
del:"Zmaza\u0165 tabu\u013Eku",
row:"Riadok",
col:"St\u013Apec",
cell:"Bunka"
},
autosave:{
unload_msg:"Vykonan\u00E9 zmeny bud\u00FA straten\u00E9, ak opust\u00ED\u0161 t\u00FAto str\u00E1nku."
},
fullscreen:{
desc:"Prepn\u00FA\u0165 zobrazenie na celej obrazovke"
},
media:{
desc:"Vlo\u017Ei\u0165 / editova\u0165 vnoren\u00E9 m\u00E9di\u00E1",
edit:"Editova\u0165 vnoren\u00E9 m\u00E9di\u00E1"
},
fullpage:{
desc:"Vlastnosti dokumentu"
},
template:{
desc:"Vlo\u017Ei\u0165 obsah z preddefinovanej \u0161abl\u00F3ny"
},
visualchars:{
desc:"Vizu\u00E1lne ovl\u00E1dacie znaky zap/vyp."
},
spellchecker:{
desc:"Prepn\u00FA\u0165 na kontrolu pravopisu",
menu:"Nastavenia kontroly pravopisu",
ignore_word:"Vynecha\u0165 slovo",
ignore_words:"Vynecha\u0165 v\u0161etky",
langs:"Jazyky",
wait:"\u010Cakaj pros\u00EDm...",
sug:"Ponuky",
no_sug:"\u017Diadne ponuky",
no_mpell:"Bez pravopisn\u00FDch ch\u00FDb."
},
pagebreak:{
desc:"Vlo\u017Ei\u0165 zalomenie str\u00E1nky."
}}});

==> glpi_0.78.3.orig.tar.gz: glpi/lib/tiny_mce/langs/sk.js <==
tinyMCE.addI18n({sk:{
common:{
edit_confirm:"Chcete pou\u017Ei\u0165 WYSIWYG m\u00F3d pre tento text?",
apply:"Pou\u017Ei\u0165",
insert:"Vlo\u017Ei\u0165",
update:"Aktualizova\u0165",
cancel:"Zru\u0161i\u0165",
close:"Zavrie\u0165",
browse:"Prech\u00E1dza\u0165",
class_name:"Trieda",
not_set:"-- Nezadan\u00E9 --",
clipboard_msg:"Funkcie kop\u00EDrova\u0165/vysrihn\u00FA\u0165/vlo\u017Ei\u0165 nie su podporovan\u00E9 prehliada\u010Dmi Mozilla a Firefox.\nChcete viac inform\u00E1ci\u00ED o tomto probl\u00E9me?",
clipboard_no_support:"Moment\u00E1lne nie je podporovan\u00E9 va\u0161\u00EDm prehliada\u010Dom. Miesto toho pou\u017Eite kl\u00E1vesov\u00FA skratku.",
popup_blocked:"Ospravedl\u0148ujeme sa, ale v\u00E1\u0161 blokova\u010D vyskakovac\u00EDch okien neumo\u017Enil otvori\u0165 okno, ktor\u00E9 sprostredkov\u00E1va funk\u010Dnos\u0165 aplik\u00E1cie. Mus\u00EDte vypn\u00FA\u0165 blokovanie vyskakovac\u00EDch okien pre tento web, aby bolo mo\u017En\u00E9 pou\u017Ei\u0165 t\u00FAto funkciu.",
invalid_data:"Chyba: Boli zadan\u00E9 neplatn\u00E9 hodnoty (zv\u00FDraznen\u00E9 \u010Dervenou)",
more_colors:"Viac farieb"
},
contextmenu:{
align:"Umiestnenie",
left:"V\u013Eavo",
center:"Na stred",
right:"Vpravo",
full:"Do bloku"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Vlo\u017Ei\u0165 d\u00E1tum",
inserttime_desc:"Vlo\u017Ei\u0165 \u010Das",
months_long:"Janu\u00E1r,Febru\u00E1r,Marec,Apr\u00EDl,M\u00E1j,J\u00FAn,J\u00FAl,August,September,Okt\u00F3ber,November,December",
months_short:"Jan,Feb,Mar,Apr,M\u00E1j,J\u00FAn,J\u00FAl,Aug,Sep,Okt,Nov,Dec",
day_long:"Nede\u013Ea,Pondelok,Utorok,Streda,\u0160tvrtok,Piatok,Sobota,Nede\u013Ea",
day_short:"Ned,Pon,Ut,Str,\u0160tvr,Pia,Sob,Ned"
},
print:{
print_desc:"Vytla\u010Di\u0165"
},
preview:{
preview_desc:"N\u00E1h\u013Ead"
},
directionality:{
ltr_desc:"Smer textu z \u013Eava do prava",
rtl_desc:"Smer textu z prava do \u013Eava"
},
layer:{
insertlayer_desc:"Vlo\u017Ei\u0165 nov\u00FA vrstvu",
forward_desc:"Posun\u00FA\u0165 dopredu",
backward_desc:"Posun\u00FA\u0165 dozadu",
absolute_desc:"Prepn\u00FA\u0165 na absol\u00FAtne poziciovanie",
content:"Nov\u00E1 vrstva..."
},
save:{
save_desc:"Ulo\u017Ei\u0165",
cancel_desc:"Zru\u0161i\u0165 v\u0161etky zmeny"
},
nonbreaking:{
nonbreaking_desc:"Vlo\u017Ei\u0165 znak nezalomen\u00E1 medzera (non-breaking space)"
},
iespell:{
iespell_desc:"Spusti\u0165 kontrolu pravopisu",
download:"ieSpell nebol n\u00E1jden\u00FD. Chcete ho nain\u0161talova\u0165?"
},
advhr:{
advhr_desc:"Horizont\u00E1lny odde\u013Eova\u010D"
},
emotions:{
emotions_desc:"Emotikony"
},
searchreplace:{
search_desc:"N\u00E1jdi",
replace_desc:"N\u00E1jdi/nahra\u010F"
},
advimage:{
image_desc:"Vlo\u017Ei\u0165/upravi\u0165 obr\u00E1zok"
},
advlink:{
link_desc:"Vlo\u017Ei\u0165/upravi\u0165 odkaz"
},
xhtmlxtras:{
cite_desc:"Cit\u00E1cia",
abbr_desc:"Skratka",
acronym_desc:"Acronym",
del_desc:"Zru\u0161enie",
ins_desc:"Vlo\u017Eenie",
attribs_desc:"Vlo\u017Ei\u0165/upravi\u0165 atrib\u00FAty"
},
style:{
desc:"Upravi\u0165 CSS"
},
paste:{
paste_text_desc:"Vlo\u017Ei\u0165 ako neformatovan\u00FD text",
paste_word_desc:"Vlo\u017Ei\u0165 text z aplik\u00E1cie Word",
selectall_desc:"Ozna\u010Di\u0165 v\u0161etko"
},
paste_dlg:{
text_title:"Pou\u017Eite CTRL+V na kl\u00E1vesnici pre vlo\u017Eenie textu do okna.",
text_linebreaks:"Zachova\u0165 zalamovanie riadkov",
word_title:"Pou\u017Eite CTRL+V na kl\u00E1vesnici pre vlo\u017Eenie textu do okna."
},
table:{
desc:"Vlo\u017Ei\u0165 nov\u00FA tabu\u013Eku",
row_before_desc:"Vlo\u017Ei\u0165 riadok pred",
row_after_desc:"Vlo\u017Ei\u0165 riadok za",
delete_row_desc:"Odstr\u00E1ni\u0165 riadok",
col_before_desc:"Vlo\u017Ei\u0165 st\u013Apec pred",
col_after_desc:"Vlo\u017Ei\u0165 st\u013Apec za",
delete_col_desc:"Odstr\u00E1ni\u0165 st\u013Apec",
split_cells_desc:"Rozdeli\u0165 zl\u00FA\u010Den\u00E9 bunky",
merge_cells_desc:"Zl\u00FA\u010Di\u0165 bunky",
row_desc:"Vlastnosti riadky tabu\u013Eky",
cell_desc:"Vlastnosti bunky tabu\u013Eky",
props_desc:"Vlastnosti tabu\u013Eky",
paste_row_before_desc:"Vlo\u017Ei\u0165 riadok pred",
paste_row_after_desc:"Vlo\u017Ei\u0165 riadok za",
cut_row_desc:"Vystrihn\u00FA\u0165 riadok",
copy_row_desc:"Kop\u00EDrova\u0165 riadok",
del:"Zmaza\u0165 tabu\u013Eku",
row:"Riadok",
col:"St\u013Apec",
cell:"Bunka"
},
autosave:{
unload_msg:"Ak opust\u00EDte t\u00FAto str\u00E1nku, vykonan\u00E9 zmeny bud\u00FA straten\u00E9."
},
fullscreen:{
desc:"Prepn\u00FA\u0165 zobrazenie na cel\u00FA obrazovku"
},
media:{
desc:"Vlo\u017Ei\u0165/upravi\u0165 vnoren\u00E9 m\u00E9di\u00E1",
edit:"Upravi\u0165 vnoren\u00E9 m\u00E9di\u00E1"
},
fullpage:{
desc:"Vlastnosti dokumentu"
},
template:{
desc:"Vlo\u017Ei\u0165 obsah z preddefinovanej \u0161abl\u00F3ny"
},
visualchars:{
desc:"Vizu\u00E1lne ovl\u00E1dacie znaky zap/vyp."
},
spellchecker:{
desc:"Prepn\u00FA\u0165 na kontrolu pravopisu",
menu:"Nastavenie kontroly pravopisu",
ignore_word:"Vynecha\u0165 slovo",
ignore_words:"Vynecha\u0165 v\u0161etky",
langs:"Jazyky",
wait:"\u010Cakaj pros\u00EDm...",
sug:"Ponuky",
no_sug:"\u017Diadne ponuky",
no_mpell:"Bez pravopisn\u00FDch ch\u00FDb."
},
pagebreak:{
desc:"Vlo\u017Ei\u0165 zalomenie str\u00E1nky."
}}});
